/*******************************************************************************
* File Name: main.c
*
* Version: 1.00
*
* Description:
*   This example project uses ADC, DMA and VDAC components along with the LCD
*     status register. ADC output is transferred to VDAC input register using
*   the DMA.
*
* Note that this file contains the DMA_Config function as well.
*
********************************************************************************
* Copyright 2012, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#include <project.h>

/* DMA Configuration constants for DMA_1 */
#define DMA_1_BYTES_PER_BURST (1u)
#define DMA_1_REQUEST_PER_BURST (1u)
#define DMA_1_SRC_BASE (CYDEV_PERIPH_BASE)
#define DMA_1_DST_BASE (CYDEV_PERIPH_BASE)

void DMA_Config(void);


/*******************************************************************************
* Function Name: main
********************************************************************************
*
* Summary:
*  main() performs following functions:
*  1: Starts the components
*  2: Calls function DMA_Config to setup the DMA.
*  3: Starts ADC continuous conversion.
*  4: Gets the converted result and displays it in LCD. Also displays VDAC data
*     register value on LCD.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
int main()
{
    /* Start the components */
    LCD_Char_1_Start();
    VDAC8_1_Start();
    ADC_DelSig_1_Start();

    /* Configure DMA to transfer ADC output to VDAC input register */
    DMA_Config();

    /* Start the ADC conversion */
    ADC_DelSig_1_StartConvert();

    LCD_Char_1_Position(0u, 0u);
    LCD_Char_1_PrintString("ADC Output: ");
    LCD_Char_1_Position(1u, 0u);
    LCD_Char_1_PrintString("DAC Input: ");

    for(;;)
    {
        /* If converted ADC value has been transferred to VDAC, print results */
        if(Status_Reg_1_Read())
        {
        /* Print the ADC output value on LCD */
        LCD_Char_1_Position(0u, strlen("ADC Output: "));
        LCD_Char_1_PrintInt16(ADC_DelSig_1_GetResult16());

        /* Print the DAC Data register value */
        LCD_Char_1_Position(1u, strlen("DAC Input: "));
        LCD_Char_1_PrintInt8(VDAC8_1_Data);
        }
    }
}


/*******************************************************************************
* Function Name:  DMA_Config
********************************************************************************
*
* Summary:
*    Code generated by the DMA Wizard.
*
*    DMA_Config() performs following functions:
*  1: Initializes the DMA channel
*  2: Allocates Transfer Descriptors
*  3: Configures the TD.
*  4: Sets source and destination address for this TD.
*  5: Initializes the TD.
*  6: Enables the DMA channel.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
*******************************************************************************/
void DMA_Config()
{
    /* Variable declarations for DMA_1 */
    uint8 DMA_1_Chan;
    uint8 DMA_1_TD[1] = {0};

    /* Iniitialize DMA channel */
    DMA_1_Chan = DMA_1_DmaInitialize(DMA_1_BYTES_PER_BURST, DMA_1_REQUEST_PER_BURST,
                                     HI16(DMA_1_SRC_BASE), HI16(DMA_1_DST_BASE));

    /* Allocate TD */
    DMA_1_TD[0] = CyDmaTdAllocate();

    /* TD configuration setting */
    CyDmaTdSetConfiguration(DMA_1_TD[0], 1u, DMA_INVALID_TD, DMA_1__TD_TERMOUT_EN);

    /* Set Source and Destination address */
    CyDmaTdSetAddress(DMA_1_TD[0], LO16((uint32)ADC_DelSig_1_DEC_SAMP_PTR),
                      LO16((uint32)VDAC8_1_Data_PTR));

    /* TD initialization */
    CyDmaChSetInitialTd(DMA_1_Chan, DMA_1_TD[0]);

    /* Enable the DMA channel */
    CyDmaChEnable(DMA_1_Chan, 1u);
}


/* [] END OF FILE */
